from matplotlib import pyplot

emma = Line('emma')
xpas = (10,10,10)
cells = 42
angle = 360/cells
d_offset = -34.048 * mm
f_offset = -7.514 * mm
#lengths
ld = 210 * mm
sd = 50 * mm
fq = 58.782 * mm
dq = 75.699 * mm
# quad radius
fr = 37 * mm
dr = 53 * mm
#field
fb = -6.695 * fr * T
db = 4.704 * dr * T


emma.add(DRIFT('ld', XL=ld/cm/2))
emma.add(CHANGREF(ALE=angle))
emma.add(CHANGREF(YCE=d_offset/cm))
emma.add(QUADRUPO('defoc', XL=dq/cm, R_0=dr/cm, B_0=db/kgauss, XPAS=xpas, KPOS=1))
emma.add(CHANGREF(YCE=-d_offset/cm))
emma.add(DRIFT('sd', XL=sd/cm))
emma.add(CHANGREF(YCE=f_offset/cm))
emma.add(QUADRUPO('foc', XL=fq/cm, R_0=fr/cm, B_0=fb/kgauss, XPAS=xpas, KPOS=1))
emma.add(CHANGREF(YCE=-f_offset/cm))
emma.add(DRIFT('ld', XL=ld/cm/2))


data = gcp.get_cell_properties(cell=emma, min_ke=10e6, max_ke=20e6, ke_steps=11, particle='e')
print gcp.cell_properties_table(data, ["KE", "stable", "Y", "T", "NU_Y", "NU_Z"])

pyplot.plot(data['KE']/1e6, data['NU_Y'], label="NU_Y")
pyplot.plot(data['KE']/1e6, data['NU_Z'], label="NU_Z")
pyplot.xlabel("KE (MeV)")
pyplot.ylabel("Tune")
pyplot.legend()
pyplot.savefig("emma_tune.pdf")

gcp.plot_cell_tracks(cell=emma, data=data, particle='e', output_file='emma_cell.pdf')

